########################################################################
## Integral Transform Method for Sufficient Dimension Reduction
##
## Reference: 
##   Peng Zeng and Yu Zhu (2010). An integral transform method for 
##      estimating the central mean and central Subspaces.
##      Journal of Multivariate Analysis 101, 271--290.
##
## Peng Zeng @ Auburn University
## 03-30-2010
########################################################################
## The code is written in a mixture of R and C
##
## In Windows system, you may directly load "IntTrans-clib.dll".
## If you want to compile the C file, use the following command. 
## "Rcmd SHLIB IntTrans-clib.c -lRblas"
##
## In Unix/Linux system, you have to first compile C code using
## "R CMD SHLIB IntTrans-clib.c"
## and then load "IntTrans-clib.so".
########################################################################
## arguments
## hx, hy   ---  sigma_u, sigma_v in the paper
## h        ---  bandwidth
## space    ---  "mean" for central mean subspace
##               "pdf"  for central subspace
## xdensity ---  "normal" if the distribution of x is normal
##               "kernel" if using kernel density estimate
##               "elliptic" if the distribution is elliptically contoured
########################################################################

rm(list = ls())
source("IntTrans.R")                ## load R codes
dyn.load("IntTrans-clib.dll")       ## load compiled C codes

c1 = matrix(rep(c(1, -1), 5), ncol = 1)
c2 = matrix(c(1, 1, rep(-1, 6), 1, 1), ncol = 1)
cvec = cbind(c1, -c1, c2)
percent = c(0.5, 0.3, 0.2)
x  = rmixnorm(1000, 10, percent, cvec)
b1 = c(rep(1, 4), rep(0, 6))
b2 = c(rep(0, 6), rep(1, 4))
e  = rnorm(1000)
y  = abs(x %*% b1 + e) / (2 + abs(x %*% b2 - 4 + e)) 

## estimate central mean subspace, assuming normal distribution
ans1 = ITM(x, y, 5, space = "mean", xdensity = "normal")
pm.dist(ans1$evectors[, 1:2], cbind(b1, b2))

## estimate central subspace, assuming normal distribution
ans2 = ITM(x, y, 5, 0.5, space = "pdf", xdensity = "normal")
pm.dist(ans2$evectors[, 1:2], cbind(b1, b2))

## estimate central mean subspace, using kernel density estimator
ans3 = ITM(x, y, 5, h = 1.5, space = "mean", xdensity = "kernel")
pm.dist(ans3$evectors[, 1:2], cbind(b1, b2))

## estimate central subspace, using kernel density estimator
ans4 = ITM(x, y, 5, 0.5, h = 1.5, space = "pdf", xdensity = "kernel")
pm.dist(ans4$evectors[, 1:2], cbind(b1, b2))

## estimate central mean subspace, assuming elliptically contoured
ans5 = ITM(x, y, 5, h = 0.5, space = "mean", xdensity = "elliptic")
pm.dist(ans5$evectors[, 1:2], cbind(b1, b2))

## estimate central subspace, assuming elliptically contoured
ans6 = ITM(x, y, 5, 0.5, h = 0.5, space = "pdf", xdensity = "elliptic")
pm.dist(ans6$evectors[, 1:2], cbind(b1, b2))

########################################################################
